@@ -16,15 +16,6 @@
 Optimizer = R6Class("Optimizer",
   public = list(
 
-    #' @field param_classes (`character()`).
-    param_classes = NULL,
-
-    #' @field properties (`character()`).
-    properties = NULL,
-
-    #' @field packages (`character()`).
-    packages = NULL,
-
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     #'
@@ -32,17 +23,16 @@ Optimizer = R6Class("Optimizer",
     #' @param param_classes (`character()`).
     #' @param properties (`character()`).
     #' @param packages (`character()`).
-    initialize = function(param_set, param_classes, properties,
-      packages = character()) {
+    initialize = function(param_set, param_classes, properties, packages = character()) {
       private$.param_set = assert_param_set(param_set)
-      self$param_classes = assert_subset(param_classes,
+      private$.param_classes = assert_subset(param_classes,
         c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct", "ParamUty"))
       # has to have at least multi-crit or single-crit property
-      self$properties = assert_subset(properties,
-        bbotk_reflections$optimizer_properties, empty.ok = FALSE)
-      self$packages = assert_set(packages)
+      private$.properties = assert_subset(properties, bbotk_reflections$optimizer_properties, empty.ok = FALSE)
+      private$.packages = union("bbotk", assert_character(packages, any.missing = FALSE, min.chars = 1L))
 
-      check_packages_installed(self$packages, msg = sprintf("Package '%%s' required but not installed for Optimizer '%s'", format(self)))
+      check_packages_installed(self$packages,
+        msg = sprintf("Package '%%s' required but not installed for Optimizer '%s'", format(self)))
     },
 
     #' @description
@@ -74,15 +64,42 @@ Optimizer = R6Class("Optimizer",
       optimize_default(inst, self, private)
     }
   ),
+
   active = list(
+
     #' @field param_set ([paradox::ParamSet]).
     param_set = function(rhs) {
       if (!missing(rhs) && !identical(rhs, private$.param_set)) {
-        stop("param_set is read-only.")
+        stop("$param_set is read-only.")
       }
       private$.param_set
+    },
+
+    #' @field param_classes (`character()`).
+    param_classes = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.param_classes)) {
+        stop("$param_classes is read-only.")
+      }
+      private$.param_classes
+    },
+
+    #' @field properties (`character()`).
+    properties = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.properties)) {
+        stop("$properties is read-only.")
+      }
+      private$.properties
+    },
+
+    #' @field packages (`character()`).
+    packages = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.packages)) {
+        stop("$packages is read-only.")
+      }
+      private$.packages
     }
   ),
+
   private = list(
     .optimize = function(inst) stop("abstract"),
 
@@ -91,6 +108,9 @@ Optimizer = R6Class("Optimizer",
       assign_result_default(inst)
     },
 
-    .param_set = NULL
+    .param_set = NULL,
+    .param_classes = NULL,
+    .properties = NULL,
+    .packages = NULL
   )
 )
